@@ -184,10 +184,11 @@ class MockOpen(Mock):
             self.__files[path] = child
 
         # Each call to `open` should reset the position in the file according to the mode.
-        if mode and 'a' in mode and not self._mock_wraps:
-            self.__files[path]._reset_position(0, SEEK_END)
-        else:
-            self.__files[path]._reset_position()
+        if not self._mock_wraps:
+            if mode and 'a' in mode:
+                self.__files[path]._reset_position(0, SEEK_END)
+            else:
+                self.__files[path]._reset_position()
 
         self._mock_return_value = child
         return child
